# Ensembl Python general-purpose utils

Centralise generic Python utils used by other project within Ensembl design to facilitate frequent tasks such as input file path checks, archive files IO manipulation or logging setup, among others.

## Contents
Check out [installation](install.md) section for further information on how to install the project.

1. [Install](install.md)
2. [Usage](usage.md)
3. [Code of Conduct](code_of_conduct.md)
4. [Coverage report](coverage.md)
5. [Code reference](reference/)

## License
Software as part of [Ensembl Python general-purpose utils](https://github.com/Ensembl/ensembl-utils) is distributed under the [Apache-2.0 License](https://www.apache.org/licenses/LICENSE-2.0.txt).
